.. _intro:

Introduction
============

Welcome to the ORBIT documentation! These next few pages will provide a brief
overview of balance-of-system cost modeling, a description of the model design
and a tutorial for getting started with ORBIT.

.. toctree::
   :maxdepth: 1

   overview
   bos
